/**
 * Copyright (c) 2013 Jorge Puig de la Bellacasa
 * Licencia GNU
 */
package edu.uoc.recetario.arquitectura;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;

/**
 * Factora de conexiones a la base de datos
 * Las propiedades de la conexin deben ser configuradas en el archivo
 * "db.properties" situado en el package "cfg"
 * @author Jorge Puig de la Bellacasa
 * 
 */
public class ConexionFactory {

	/**
	 * Devuelve un objeto de tipo Connection segn la configuracin
	 * del archivo db.properties
	 * 
	 * @return Connection
	 * @throws SQLException
	 */
	static public Connection getConnection() throws SQLException {
		Connection c = null;
		try {
			Class.forName(Configuracion.getDBConfig("driver")).newInstance();
		} catch (Exception e) {
			throw new SQLException("El driver JDBC ["
					+ Configuracion.getDBConfig("driver")
					+ "] no existe en el classpath o no se puede instanciar: "
					+ e.getMessage(), e.getCause());
		}
		c = DriverManager.getConnection(Configuracion.getDBConfig("url")
				+ Configuracion.getDBConfig("dbName"),
				Configuracion.getDBConfig("userName"),
				Configuracion.getDBConfig("password"));
		System.out.println("Connected to the database");
		return c;
	}

}
