/**
 * Copyright (c) 2013 Jorge Puig de la Bellacasa
 * Licencia GNU
 */
package edu.uoc.recetario.arquitectura;

import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;

/**
 * Carga los archivos de configuracin
 * 
 * @author Jorge Puig de la Bellacasa
 * 
 */
public class Configuracion {

	
	/** path del archivo de configuracin de la base de datos*/
	static final private String DB_FILE = "cfg/db.properties";
	/** propiedades del archivo de configuracin de la base de datos*/
	static private Properties DB_CONFIG;
	/** path del archivo de configuracin del contenedor web*/
	static final private String S_FILE = "cfg/s.properties";
	/** propiedades del archivo de configuracin del contenedor web*/
	static private Properties S_CONFIG;

	
	/**
	 * Devuelve el valor de la propiedad pasada como parmetro
	 * @param _key identificador de la propiedad a recuperar
	 * @return valor de la propiedad 
	 * @throws RuntimeException
	 */
	static public String getDBConfig(String _key) throws RuntimeException {
		if (DB_CONFIG == null) {
			try {
				InputStream is = Configuracion.class
						.getResourceAsStream("/cfg/db.properties");
				DB_CONFIG = new Properties();
				DB_CONFIG.load(is);
			} catch (IOException e) {
				DB_CONFIG = null;
				throw new RuntimeException(
						"Se han producido errores al cargar el archivo de configuracin de DB ["
								+ DB_FILE + "]", e);
			}
		}
		return DB_CONFIG.getProperty(_key, null);
	}
	
	/**
	 * Devuelve el valor de la propiedad pasada como parmetro
	 * @param _key identificador de la propiedad a recuperar
	 * @return valor de la propiedad 
	 * @throws RuntimeException
	 */
	static public String getSConfig(String _key) throws RuntimeException {
		if (S_CONFIG == null) {
			try {
				InputStream is = Configuracion.class
						.getResourceAsStream("/cfg/s.properties");
				S_CONFIG = new Properties();
				S_CONFIG.load(is);
			} catch (IOException e) {
				S_CONFIG = null;
				throw new RuntimeException(
						"Se han producido errores al cargar el archivo de configuracin del contenedor web ["
								+ S_FILE + "]", e);
			}
		}
		return S_CONFIG.getProperty(_key, null);
	}
}
