/**
 * Copyright (c) 2013 Jorge Puig de la Bellacasa
 * Licencia GNU
 */
package edu.uoc.recetario.arquitectura.businessLogic;

import java.io.Serializable;
import java.sql.Connection;
import java.sql.SQLException;
import java.util.Collection;

import edu.uoc.recetario.arquitectura.dao.IDao;
import edu.uoc.recetario.arquitectura.pojo.IPojo;

/**
 * Clase abstracta que implementa la lgica de negocio. Las clases
 * correspondientes a la lgica de negocio de cada tabla heredan de sta.
 * 
 * @author Jorge Puig de la Bellacasa
 * @param <T> Pojo sobre el que trabaja esta lgica de negocio
 * 
 */
public abstract class BusinessLogicAbs<T extends IPojo> implements
		IBusinessLogic<T> {

	/**
	 * Data Access Object que utiliza esta lgica de negocio
	 * 
	 * @return el DAO de esta lgica de negocio
	 */
	protected abstract IDao<T> getDao();

	/**
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.recetario.arquitectura.businessLogic.IBusinessLogic#save(java.sql.Connection,
	 *      edu.uoc.recetario.arquitectura.pojo.IPojo)
	 */
	@Override
	public Object save(Connection _con, T _p) throws SQLException {
		return this.getDao().save(_con, _p);
	}

	/**
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.recetario.arquitectura.businessLogic.IBusinessLogic#delete(java.sql.Connection,
	 *      java.io.Serializable)
	 */
	@Override
	public boolean delete(Connection _con, Serializable _pk)
			throws SQLException {
		return this.getDao().delete(_con, _pk);
	}

	/**
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.recetario.arquitectura.businessLogic.IBusinessLogic#update(java.sql.Connection,
	 *      edu.uoc.recetario.arquitectura.pojo.IPojo)
	 */
	@Override
	public void update(Connection _con, T _p) throws SQLException {
		this.getDao().update(_con, _p);
	}

	/**
	 * (non-Javadoc)
	 * 
	 * @throws Exception
	 * 
	 * @see edu.uoc.recetario.arquitectura.businessLogic.IBusinessLogic#load(java.sql.Connection,
	 *      java.io.Serializable)
	 */
	@Override
	public T load(Connection _con, Serializable _pk) throws Exception {
		return this.getDao().load(_con, _pk);
	}

	/**
	 * (non-Javadoc)
	 * 
	 * @throws Exception
	 * 
	 * @see edu.uoc.recetario.arquitectura.businessLogic.IBusinessLogic#list(java.sql.Connection)
	 */
	@Override
	public Collection<T> list(Connection _con) throws Exception {
		return this.getDao().list(_con);
	}

}
