/**
 * Copyright (c) 2013 Jorge Puig de la Bellacasa
 * Licencia GNU
 */
package edu.uoc.recetario.arquitectura.businessLogic;

import java.io.Serializable;
import java.sql.Connection;
import java.sql.SQLException;
import java.util.Collection;

import edu.uoc.recetario.arquitectura.pojo.IPojo;

/**
 * Interfaz que debern implementar las clases de tipo BussinesLogic
 * 
 * @author Jorge Puig de la Bellacasa
 * @param <T> Pojo sobre el que trabaja esta lgica de negocio
 * 
 */
public interface IBusinessLogic<T extends IPojo> {

	/**
	 * Guarda la entrada pasada por parmetro en la tabla correspondiente de la base de datos
	 * 
	 * @param _con Connection a utilizar
	 * @param _p Objeto de tipo Pojo que representa la entrada a introducir
	 * @return El identificador nico de este Pojo
	 * @throws SQLException
	 */
	public abstract Object save(Connection _con, T _p) throws SQLException;

	/**
	 * Elimina la entrada de la tabla cuya clave primaria coincide con la cadena
	 * pasada por parmetro
	 * @param _con Connection a utilizar
	 * @param _pk Clave primaria de la entrada a eliminar
	 * @return true si exista una entrada con la clave primaria pasada por parmetro
	 * @throws SQLException
	 */
	public abstract boolean delete(Connection _con, Serializable _pk)
			throws SQLException;

	/**
	 * Actualiza los datos de la entrada correspondiente
	 * @param _con Connection a utilizar
	 * @param _p objeto de tipo pojo con los datos a actualizar (obviamente la 
	 * clave primaria debe coincidir con el identificador del objeto)
	 * @throws SQLException
	 */
	public void update(Connection _con, T _p) throws SQLException;

	/**
	 * obtiene la entrada de la tabla cuya clave primaria coincide con el identificador 
	 * pasado por parmetro
	 * 
	 * @param _con Connection a utilizar
	 * @param _pk valor de la clave primaria de la entrada a recuperar
	 * @return un objeto de tipo pojo que representa la entrada obtenida
	 * @throws SQLException
	 * @throws Exception 
	 */
	public abstract T load(Connection _con, Serializable _pk)
			throws SQLException, Exception;

	/**
	 * Obtiene un listado con todas las entradas de la tabla
	 * 
	 * @param _con Connection a utilizar
	 * @return Collection con todas las entradas de la tabla en formato Pojo
	 * @throws SQLException
	 * @throws Exception 
	 */
	public abstract Collection<T> list(Connection _con) throws SQLException, Exception;

}