/**
 * Copyright (c) 2013 Jorge Puig de la Bellacasa
 * Licencia GNU
 */
package edu.uoc.recetario.arquitectura.businessLogic;

import java.io.Serializable;
import java.sql.Connection;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Collection;

import edu.uoc.recetario.arquitectura.dao.IDao;
import edu.uoc.recetario.arquitectura.dao.UsuarioDao;
import edu.uoc.recetario.arquitectura.pojo.UsuarioPojo;

/**
 * Implementa la lgica de negocio de la tabla USUARIO
 * 
 * @author Jorge Puig de la Bellacasa
 * 
 */
public class UsuarioBusinessLogic extends BusinessLogicAbs<UsuarioPojo> {

	
	/** DAO de la tabla USUARIO */
	private final UsuarioDao dao = new UsuarioDao();

 
	/**
	 * Devuelve un ArrayList con todas las entradas de la tabla USUARIO cuyo 
	 * identificador contiene la cadena pasada por parmetro
	 * @param _con Connection a utilizar
	 * @param _id cadena que debern contener los identificadores de los usuarios a recuperar
	 * @return ArrayList de objetos de tipo Pojo con todos los usuarios cuyo identificador
	 * contiene la cadena pasada por parmetro
	 * @throws SQLException
	 */
	public Collection<UsuarioPojo> listByName(Connection _con, Serializable _id)
			throws SQLException {
		Collection<UsuarioPojo> r = null;
		final String query = "SELECT IdUsuario, Contrasena, Email, TipoUsuario FROM USUARIO WHERE LOWER(idUsuario) LIKE LOWER(?)";
		Collection<Object[]> myL = getDao().listBySQL(_con, query,
				new Object[] { "%" + _id + "%" });
		if (myL != null) {
			r = new ArrayList<UsuarioPojo>();
			for (Object[] row : myL) {
				UsuarioPojo p = new UsuarioPojo();
				p.setId(row[0].toString());
				p.setContrasena(row[1].toString());
				p.setEmail(row[2].toString());
				p.setTipoUsuario(row[3].toString());
				r.add(p);
			}
		}
		return r;
	}
	
	
	/**
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.recetario.arquitectura.businessLogic.BusinessLogicAbs#getDao()
	 */
	@Override
	protected IDao<UsuarioPojo> getDao() {
		return this.dao;
	}
}
