/**
 * Copyright (c) 2013 Jorge Puig de la Bellacasa
 * Licencia GNU
 */
package edu.uoc.recetario.arquitectura.dao;

import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Types;

import edu.uoc.recetario.arquitectura.pojo.ComentarioPojo;

/**
 * DAO de la tabla COMENTARIO
 * 
 * @author Jorge Puig de la Bellacasa
 * 
 */
public class ComentarioDao extends DaoAbs<ComentarioPojo> {

	/** Nombre de la tabla en la que se encuentran los comentarios en la base de datos */
	private final String tableName = "comentario";
	/** Campo que representa la clave primaria de la relacin */
	private final String idField = "IdComentario";
	/** Array de atributos de la relacin */
	private final String[] fields = new String[] { "IdComentario", "Texto", "IdUsuario", "IdReceta"};

	/**
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.recetario.arquitectura.dao.DaoAbs#getTableName()
	 */
	@Override
	protected String getTableName() {
		return this.tableName;
	}

	/**
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.recetario.arquitectura.dao.DaoAbs#getIdField()
	 */
	@Override
	protected String getIdField() {
		return this.idField;
	}

	/**
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.recetario.arquitectura.dao.DaoAbs#getFields()
	 */
	@Override
	protected String[] getFields() {
		return this.fields;
	}


	/**
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.recetario.arquitectura.dao.DaoAbs#createPojo(java.sql.ResultSet)
	 */
	@Override
	protected ComentarioPojo createPojo(ResultSet rs) throws SQLException {
		ComentarioPojo r = new ComentarioPojo();
		r.setId(rs.getInt(1));
		r.setTexto(rs.getString(2));
		r.setIdUsuario(rs.getString(3));
		r.setIdReceta(rs.getInt(4));
		return r;
	}
	

	/**
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.recetario.arquitectura.dao.DaoAbs#setStatement(java.sql.PreparedStatement,
	 *      edu.uoc.recetario.arquitectura.pojo.IPojo)
	 */
	@Override
	protected int setStatement(PreparedStatement _st, ComentarioPojo _p)
			throws SQLException {
		int r = 1;
		if (_p.getId() == null) {
			_st.setNull(r, Types.INTEGER);
		} else {
			_st.setInt(r, _p.getId());
		}
		r++;
		if (_p.getTexto() == null) {
			_st.setNull(r, Types.VARCHAR);
		} else {
			_st.setString(r, _p.getTexto());
		}
		r++;
		if (_p.getIdUsuario() == null){
			_st.setNull(r, Types.VARCHAR);
		} else {		
			_st.setString(r, _p.getIdUsuario());
		}
		r++;
		if (_p.getIdReceta() == null){
			_st.setNull(r, Types.INTEGER);
		} else {		
			_st.setInt(r, _p.getIdReceta());
		}
		return (r + 1);
	}

}
