/**
 * Copyright (c) 2013 Jorge Puig de la Bellacasa
 * Licencia GNU
 */
package edu.uoc.recetario.arquitectura.dao;

import java.io.Serializable;
import java.sql.Connection;
import java.sql.SQLException;
import java.util.Collection;

import edu.uoc.recetario.arquitectura.pojo.IPojo;

/**
 * Interfaz que debern implementar todos los objetos de tipo DAO
 * para el acceso a datos de la tabla correspondiente
 * 
 * @author Jorge Puig de la Bellacasa
 * @param <T> Pojo sobre el que trabaja este DAO
 * 
 */
public interface IDao<T extends IPojo> {

	/**
	 * crea una nueva entrada en la tabla correspondiente de la base de datos
	 * 
	 * @param _con Connection a utilizar
	 * @param _p objeto de tipo Pojo que representa la nueva entrada
	 * @return identificador nico de este Pojo
	 * @throws SQLException
	 */
	public abstract Object save(Connection _con, T _p) throws SQLException;

	/**
	 * elimina una entrada de la tabla correspondiente en la base de datos
	 * @param _con Connection a utilizar
	 * @param _pk Clave principal de la entrada a eliminar
	 * @return true si la operacin se ha realizado con xito
	 * @throws SQLException
	 */
	public abstract boolean delete(Connection _con, Serializable _pk)
			throws SQLException;

	/**
	 * Actualiza los datos de una entrada en la tabla correspondiente de la base de datos
	 * @param _con Connection a utilizar
	 * @param _p objeto de tipo Pojo con los datos a actualizar
	 * @throws SQLException
	 */
	public void update(Connection _con, T _p) throws SQLException;

	/**
	 * Obtiene una entrada de la tabla correspondiente segn la clave principal proporcionada
	 * 
	 * @param _con Connection a utilizar
	 * @param _pk valor de la clave principal
	 * @return objeto de tipo Pojo que representa la entrada de la tabla
	 * @throws SQLException
	 * @throws Exception 
	 */
	public abstract T load(Connection _con, Serializable _pk)
			throws SQLException, Exception;

	
	/**
	 * Devuelve todas las entradas de la tabla correspondiente a este DAO
	 * 
	 * @param _con Connection a utilizar
	 * @return un array de tipo Pojo con todas las entradas de la tabla
	 * @throws SQLException
	 * @throws Exception 
	 */
	public abstract Collection<T> list(Connection _con) throws SQLException, Exception;

	
	/**
	 * Realiza una consulta SQL segn la String pasada por parmetro
	 * Se utiliza para consultas ms especializadas
	 * @param _con Connection a utilizar
	 * @param _sqlQuery Consulta SQL
	 * @param _params Array con los parmetros de la consulta
	 * @return Una Collection con el resultado de la consulta
	 * @throws SQLException
	 */
	public Collection<Object[]> listBySQL(Connection _con, String _sqlQuery,
			Object[] _params) throws SQLException;

}