/**
 * Copyright (c) 2013 Jorge Puig de la Bellacasa
 * Licencia GNU
 */
package edu.uoc.recetario.arquitectura.dao;


import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Types;

import edu.uoc.recetario.arquitectura.pojo.RecetaPojo;

/**
 * DAO correspondiente a la tabla RECETA
 * 
 * @author Jorge Puig de la Bellacasa
 * 
 */
public class RecetaDao extends DaoAbs<RecetaPojo> {

	/** nombre de la tabla tal y como aparece en la base de datos */
	private final String tableName = "receta";
	/** nombre de la clave primaria */
	private final String idField = "IdReceta";
	/** array de los atributos de la tabla tal y como aparecen en la base de datos  */
	private final String[] fields = new String[] { "IdReceta", "NomReceta", "NumComensales", "IdUsuario", "Ingredientes", "Preparacion", "NomFoto"};
	
	
	/**
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.recetario.arquitectura.dao.DaoAbs#getTableName()
	 */
	@Override
	protected String getTableName() {
		return this.tableName;
	}

	/**
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.recetario.arquitectura.dao.DaoAbs#getIdField()
	 */
	@Override
	protected String getIdField() {
		return this.idField;
	}

	/**
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.recetario.arquitectura.dao.DaoAbs#getFields()
	 */
	@Override
	protected String[] getFields() {
		return this.fields;
	}
	
	/**
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.recetario.arquitectura.dao.DaoAbs#createPojo(java.sql.ResultSet)
	 */
	@Override
	protected RecetaPojo createPojo(ResultSet rs) throws SQLException, Exception {
		RecetaPojo r = new RecetaPojo();
		r.setId(rs.getInt(1));
		r.setNombreReceta(rs.getString(2));
		r.setComensales(rs.getInt(3));
		r.setIdUsuario(rs.getString(4));
		r.setIngredientes(rs.getString(5));
		r.setPreparacion(rs.getString(6));
		r.setNombreFoto(rs.getString(7));
		return r;
	}

	/**
	 * (non-Javadoc)
	 * @see edu.uoc.recetario.arquitectura.dao.DaoAbs#setStatement(java.sql.PreparedStatement,
	 *      edu.uoc.recetario.arquitectura.pojo.IPojo)
	 */
	@Override
	protected int setStatement(PreparedStatement _st, RecetaPojo _p)
			throws SQLException {
		int r = 1;
		if (_p.getId() == null) {
			_st.setNull(r, Types.INTEGER);
		} else {
			_st.setInt(r, _p.getId());
		}
		r++;
		if (_p.getNombreReceta() == null) {
			_st.setNull(r, Types.VARCHAR);
		} else {
			_st.setString(r, _p.getNombreReceta());
		}
		r++;
		if (_p.getComensales() == null) {
			_st.setNull(r, Types.INTEGER);
		} else {
			_st.setInt(r, _p.getComensales());
		}
		r++;
		if (_p.getIdUsuario() == null){
			_st.setNull(r, Types.VARCHAR);
		} else {		
			_st.setString(r, _p.getIdUsuario());
		}
		r++;
		if (_p.getIngredientes() == null){
			_st.setNull(r, Types.VARCHAR);
		} else {		
			_st.setString(r, _p.getIngredientes());
		}
		r++;
		if (_p.getPreparacion() == null){
			_st.setNull(r, Types.VARCHAR);
		} else {		
			_st.setString(r, _p.getPreparacion());
		}
		r++;
		if (_p.getNombreFoto() == null){
			_st.setNull(r, Types.VARCHAR);
		} else {		
			_st.setString(r, _p.getNombreFoto());
		}
		return (r + 1);
	}

}
