/**
 * Copyright (c) 2013 Jorge Puig de la Bellacasa
 * Licencia GNU
 */
package edu.uoc.recetario.arquitectura.dao;

import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Types;

import edu.uoc.recetario.arquitectura.pojo.UsuarioPojo;

/**
 * DAO de la relacin USUARIO 
 * 
 * @author Jorge Puig de la Bellacasa
 * 
 */
public class UsuarioDao extends DaoAbs<UsuarioPojo> {

	/** nombre de la tabla tal y como aparece en la base de datos */
	private final String tableName = "usuario";
	/** nombre de la clave principal tal y como aparece en la base de datos **/
	private final String idField = "IdUsuario";
	/** Array con los nombres de todos los atributos de la tabla tal y como aparecen en la base de datos */
	private final String[] fields = new String[] { "IdUsuario", "Contrasena", "Email", "TipoUsuario" };

	/**
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.recetario.arquitectura.dao.DaoAbs#getTableName()
	 */
	@Override
	protected String getTableName() {
		return this.tableName;
	}

	/**
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.recetario.arquitectura.dao.DaoAbs#getIdField()
	 */
	@Override
	protected String getIdField() {
		return this.idField;
	}

	/**
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.recetario.arquitectura.dao.DaoAbs#getFields()
	 */
	@Override
	protected String[] getFields() {
		return this.fields;
	}

	/**
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.recetario.arquitectura.dao.DaoAbs#createPojo(java.sql.ResultSet)
	 */
	@Override
	protected UsuarioPojo createPojo(ResultSet rs) throws SQLException {
		UsuarioPojo r = new UsuarioPojo();
		r.setId(rs.getString(1));
		r.setContrasena(rs.getString(2));
		r.setEmail(rs.getString(3));
		r.setTipoUsuario(rs.getString(4));
		return r;
	}

	/**
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.recetario.arquitectura.dao.DaoAbs#setStatement(java.sql.PreparedStatement,
	 *      edu.uoc.recetario.arquitectura.pojo.IPojo)
	 */
	@Override
	protected int setStatement(PreparedStatement _st, UsuarioPojo _p)
			throws SQLException {
		int r = 1;
		if (_p.getId() == null) {
			_st.setNull(r, Types.VARCHAR);
		} else {
			_st.setString(r, _p.getId());
		}
		r++;
		if (_p.getContrasena() == null) {
			_st.setNull(r, Types.VARCHAR);
		} else {
			_st.setString(r, _p.getContrasena());
		}
		r++;
		if (_p.getEmail() == null) {
			_st.setNull(r, Types.VARCHAR);
		} else {
			_st.setString(r, _p.getEmail());
		}
		r++;
		if (_p.getTipoUsuario() == null){
			_st.setNull(r, Types.VARCHAR);
		} else {		
			_st.setString(r, _p.getTipoUsuario());
		}
		return (r+1);
	}

}
