/**
 * Copyright (c) 2013 Jorge Puig de la Bellacasa
 * Licencia GNU
 */
package edu.uoc.recetario.arquitectura.messages;

import java.util.ArrayList;
import java.util.Collection;
import java.util.HashSet;

import edu.uoc.recetario.arquitectura.messages.Message.Type;

/**
 * Lista de mensajes del sistema para enviar mensajes informativos al usuario a travs de la vista
 * 
 * @author Jorge Puig de la Bellacasa
 * 
 */
public class MessageList extends ArrayList<Message> {

	/** serialVersionUID */
	private static final long serialVersionUID = 691436107645615815L;

	/**
	 * Devuelve el nmero de mensajes en esta lista cuyo tipo coincide con el tipo pasado por parmetro
	 * @param _type tipo de mensaje
	 * @return el nmero de mensajes
	 */
	public int countByType(Type _type) {
		int i = 0;
		for (Message m : this) {
			if (m.getTipo().equals(_type)) {
				i++;
			}
		}
		return i;
	}

	/**
	 * devuelve los mensajes de tipo ERROR de esta lista
	 * @return mensajes de tipo ERROR
	 */
	public Collection<String> getErrors() {
		Collection<String> r = new HashSet<String>();
		for (Message m : this) {
			if (m.getTipo().equals(Type.ERROR)) {
				r.add(m.getMensaje());
			}
		}
		if (r.isEmpty()) {
			return null;
		}
		return r;
	}
	
	/**
	 * Devuelve los mensajes de tipo INFO de esta lista
	 * @return mensajes de tipo INFO
	 */
	public Collection<String> getInfos() {
		Collection<String> r = new HashSet<String>();
		for (Message m : this) {
			if (m.getTipo().equals(Type.INFO)) {
				r.add(m.getMensaje());
			}
		}
		if (r.isEmpty()) {
			return null;
		}
		return r;
	}

}
