/**
 * Copyright (c) 2013 Jorge Puig de la Bellacasa
 * Licencia GNU
 */
package edu.uoc.recetario.gc00;

import java.sql.Connection;
import java.sql.SQLException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.jasypt.util.password.BasicPasswordEncryptor;

import edu.uoc.recetario.arquitectura.ConexionFactory;
import edu.uoc.recetario.arquitectura.businessLogic.UsuarioBusinessLogic;
import edu.uoc.recetario.arquitectura.pojo.UsuarioPojo;

/**
 * GC00 gestin de cuenta y logout<br>
 * Implementa los casos de uso
 * <ul>
 * <li>GC01 Cerrar sesin</li>
 * <li>GC02 Cambiar datos personales</li>
 * </ul>
 * 
 * @author Jorge Puig de la Bellacasa
 * 
 */
public class GC00Script {

	/** lgica de usuario */
	static UsuarioBusinessLogic usuarioBusinessLogic = new UsuarioBusinessLogic();
	/** log */
	static final Log LOG = LogFactory.getLog(GC00Script.class);

	/**
	 * <b>GC02 Cambiar datos personales</b><br>
	 * Cambia los datos personales del usuario
	 * 
	 * @param _model Modelo con los datos proporcionados por el usuario
	 * @return <code>true</code> si el usuario y contrasea existen en el
	 *         sistema
	 * @throws SQLException
	 * @throws Exception
	 */
	public static UsuarioPojo cambiarDatos(GC00Model _model)
			throws SQLException, Exception {
		UsuarioPojo r = null;
		Connection con = null;
		try {
			con = ConexionFactory.getConnection();
			BasicPasswordEncryptor passwordEncryptor = new BasicPasswordEncryptor();
			UsuarioPojo usuario = usuarioBusinessLogic.load(con, _model
					.getUsuarioSesion().getId());
			if (usuario != null) {
				UsuarioPojo nuevoUsuario = new UsuarioPojo();
				nuevoUsuario.setId(usuario.getId());
				if (_model.getNuevaContrasena().length() > 0) {
					nuevoUsuario.setContrasena(passwordEncryptor
							.encryptPassword(_model.getNuevaContrasena()));
				} else {
					nuevoUsuario.setContrasena(usuario.getContrasena());
				}
				if (_model.getNuevoEmail().length() > 0) {
					nuevoUsuario.setEmail(_model.getNuevoEmail());
				} else {
					nuevoUsuario.setEmail(usuario.getEmail());
				}
				nuevoUsuario.setTipoUsuario(usuario.getTipoUsuario());
				usuarioBusinessLogic.update(con, nuevoUsuario);
				r = nuevoUsuario;
			}
		} catch (Throwable e) {
			logException(e);
		} finally {
			try {
				if (con != null) {
					con.close();
				}
			} catch (Exception ignore) {
				LOG.error("error cerrando conexin a la BD", ignore);
			}
		}
		return r;
	}

	/**
	 * Comprueba si la contrasea introducida por el usuario coincide con la
	 * contrasea del usuario de esta sesin
	 * 
	 * @param _model
	 * @return "true" si la contrasea coincide, "false" de otro modo
	 * @throws SQLException
	 * @throws Exception
	 */
	public static boolean autentificar(GC00Model _model) throws SQLException,
			Exception {
		boolean r = false;
		Connection con = null;
		BasicPasswordEncryptor passwordEncryptor = new BasicPasswordEncryptor();
		try {
			con = ConexionFactory.getConnection();
			UsuarioPojo usuario = usuarioBusinessLogic.load(con, _model
					.getUsuarioSesion().getId());
			if (usuario != null) {
				if (passwordEncryptor.checkPassword(_model.getContrasena(),
						_model.getUsuarioSesion().getContrasena())) {
					r = true;
				}
			}
		} catch (Throwable e) {
			logException(e);
		} finally {
			try {
				if (con != null) {
					con.close();
				}
			} catch (Exception ignore) {
				LOG.error("error cerrando conexin a la BD", ignore);
			}
		}
		return r;
	}

	/**
	 * Logea la excepcin y la vuelve a lanzar
	 * 
	 * @param _t la excepcin a logear
	 * @throws SQLException
	 * @throws Exception
	 */
	public static void logException(Throwable _t) throws SQLException,
			Exception {
		if (_t instanceof SQLException) {
			LOG.error("error en el acceso a la base de datos", _t);
			throw (SQLException) _t;
		} else {
			LOG.error("error", _t);
			throw new Exception(_t.getClass().getName() + " - "
					+ _t.getMessage(), _t.getCause());
		}
	}
}
