/**
 * Copyright (c) 2013 Jorge Puig de la Bellacasa
 * Licencia GNU
 */
package edu.uoc.recetario.gr00;

import java.io.File;
import java.util.ArrayList;
import java.util.Collection;

import edu.uoc.recetario.arquitectura.Configuracion;
import edu.uoc.recetario.arquitectura.messages.MessageList;
import edu.uoc.recetario.arquitectura.pojo.ComentarioPojo;
import edu.uoc.recetario.arquitectura.pojo.RecetaPojo;
import edu.uoc.recetario.arquitectura.pojo.UsuarioPojo;

/**
 * Encapsula los datos necesarios para realizar las tareas del grupo funcional
 * GR00(gestin de recetas)
 * 
 * @author Jorge Puig de la Bellacasa
 * 
 */
public class GR00Model {

	/** accion Solicitada */
	private String accionSolicitada;
	/** mensajes */
	private final MessageList messages = new MessageList();

	/** usuario de la sesin */
	private UsuarioPojo usuarioSesion;
	/** objeto usuario auxiliar */
	private UsuarioPojo usuario;
	/** receta */
	private RecetaPojo receta;
	/** comentario */
	private ComentarioPojo comentario;
	/** lista de recetas */
	private Collection<RecetaPojo> recetas = new ArrayList<RecetaPojo>();
	/** lista de comentarios */
	private Collection<ComentarioPojo> comentarios = new ArrayList<ComentarioPojo>();
	/** trmino de bsqueda de recetas */
	private String nombre;
	/** fotografa */
	private File fotografia;
	/** tipo mime del archivo subido */
	private String fotografiaContentType;
	/** nombre del archivo subido */
	private String fotografiaFileName;
	/** path relativo al directorio de fotografas */
	private final String uploadedImagesPath = Configuracion
			.getSConfig("uploadedImagesPath");
	/** path relativo al directorio de fotografas en trminos de URL */
	private final String displayImagesPath = Configuracion
			.getSConfig("displayImagesPath");

	/**
	 * Devuelve el valor del campo {@link #usuarioSesion}
	 * 
	 * @return Valor de tipo UsuarioPojo del campo {@link #usuarioSesion}
	 */
	public UsuarioPojo getUsuarioSesion() {
		return this.usuarioSesion;
	}

	/**
	 * Establece el valor del campo {@link #usuarioSesion}
	 * 
	 * @param usuarioSesion Valor de tipo UsuarioPojo a almacenar en el campo
	 *            {@link #usuarioSesion}
	 */
	public void setUsuarioSesion(UsuarioPojo usuarioSesion) {
		this.usuarioSesion = usuarioSesion;
	}

	/**
	 * Devuelve el valor del campo {@link #usuario}
	 * 
	 * @return Valor de tipo UsuarioPojo del campo {@link #usuario}
	 */
	public UsuarioPojo getUsuario() {
		return this.usuario;
	}

	/**
	 * Establece el valor del campo {@link #usuario}
	 * 
	 * @param usuario Valor de tipo UsuarioPojo a almacenar en el campo
	 *            {@link #usuario}
	 */
	public void setUsuario(UsuarioPojo usuario) {
		this.usuario = usuario;
	}

	/**
	 * Devuelve el valor del campo {@link #receta}
	 * 
	 * @return Valor de tipo RecetaPojo del campo {@link #receta}
	 */
	public RecetaPojo getReceta() {
		return this.receta;
	}

	/**
	 * Establece el valor del campo {@link #receta}
	 * 
	 * @param receta Valor de tipo RecetaPojo a almacenar en el campo
	 *            {@link #receta}
	 */
	public void setReceta(RecetaPojo receta) {
		this.receta = receta;
	}

	/**
	 * Devuelve el valor del campo {@link #comentario}
	 * 
	 * @return Valor de tipo ComentarioPojo del campo {@link #comentario}
	 */
	public ComentarioPojo getComentario() {
		return this.comentario;
	}

	/**
	 * Establece el valor del campo {@link #comentario}
	 * 
	 * @param comentario Valor de tipo ComentarioPojo a almacenar en el campo
	 *            {@link #comentario}
	 */
	public void setComentario(ComentarioPojo comentario) {
		this.comentario = comentario;
	}

	/**
	 * Devuelve el valor del campo {@link #recetas}
	 * 
	 * @return Valor de tipo Collection de objetos RecetaPojo del campo
	 *         {@link #recetas}
	 */
	public Collection<RecetaPojo> getRecetas() {
		return this.recetas;
	}

	/**
	 * Establece el valor del campo {@link #recetas}
	 * 
	 * @param recetas Valor de tipo Collection de objetos RecetaPojo a almacenar
	 *            en el campo {@link #recetas}
	 */
	public void setRecetas(Collection<RecetaPojo> recetas) {
		this.recetas = recetas;
	}

	/**
	 * Devuelve el valor del campo {@link #comentarios}
	 * 
	 * @return Valor de tipo Collection de objetos ComentarioPojo del campo
	 *         {@link #comentarios}
	 */
	public Collection<ComentarioPojo> getComentarios() {
		return this.comentarios;
	}

	/**
	 * Establece el valor del campo {@link #comentarios}
	 * 
	 * @param comentarios Valor de tipo Collection de objetos ComentarioPojo a
	 *            almacenar en el campo {@link #comentarios}
	 */
	public void setComentarios(Collection<ComentarioPojo> comentarios) {
		this.comentarios = comentarios;
	}

	/**
	 * Devuelve el valor del campo {@link #nombre}
	 * 
	 * @return Valor de tipo String del campo {@link #nombre}
	 */
	public String getNombre() {
		return this.nombre;
	}

	/**
	 * Establece el valor del campo {@link #nombre}
	 * 
	 * @param nombre Valor de tipo String a almacenar en el campo
	 *            {@link #nombre}
	 */
	public void setNombre(String nombre) {
		this.nombre = nombre;
	}

	/**
	 * Devuelve el valor del campo {@link #fotografia}
	 * 
	 * @return Valor de tipo File del campo {@link #fotografia}
	 */
	public File getFotografia() {
		return this.fotografia;
	}

	/**
	 * Establece el valor del campo {@link #fotografia}
	 * 
	 * @param fotografia Valor de tipo File a almacenar en el campo
	 *            {@link #fotografia}
	 */
	public void setFotografia(File fotografia) {
		this.fotografia = fotografia;
	}

	/**
	 * Devuelve el valor del campo {@link #fotografiaContentType}
	 * 
	 * @return Valor de tipo String del campo {@link #fotografiaContentType}
	 */
	public String getFotografiaContentType() {
		return this.fotografiaContentType;
	}

	/**
	 * Establece el valor del campo {@link #fotografiaContentType}
	 * 
	 * @param fotografiaContentType Valor de tipo String a almacenar en el campo
	 *            {@link #fotografiaContentType}
	 */
	public void setFotografiaContentType(String fotografiaContentType) {
		this.fotografiaContentType = fotografiaContentType;
	}

	/**
	 * Devuelve el valor del campo {@link #fotografiaFileName}
	 * 
	 * @return Valor de tipo String del campo {@link #fotografiaFileName}
	 */
	public String getFotografiaFileName() {
		return this.fotografiaFileName;
	}

	/**
	 * Establece el valor del campo {@link #fotografiaFileName}
	 * 
	 * @param fotografiaFileName Valor de tipo String a almacenar en el campo
	 *            {@link #fotografiaFileName}
	 */
	public void setFotografiaFileName(String fotografiaFileName) {
		this.fotografiaFileName = fotografiaFileName;
	}

	/**
	 * Devuelve el valor del campo {@link #accionSolicitada}
	 * 
	 * @return Valor de tipo String del campo {@link #accionSolicitada}
	 */
	public String getAccionSolicitada() {
		return this.accionSolicitada;
	}

	/**
	 * Establece el valor del campo {@link #accionSolicitada}
	 * 
	 * @param accionSolicitada Valor de tipo String a almacenar en el campo
	 *            {@link #accionSolicitada}
	 */
	public void setAccionSolicitada(String accionSolicitada) {
		this.accionSolicitada = accionSolicitada;
	}

	/**
	 * Devuelve el valor del campo {@link #messages}
	 * 
	 * @return Valor de tipo MessageList del campo {@link #messages}
	 */
	public MessageList getMessages() {
		return this.messages;
	}

	/**
	 * Devuelve el valor del campo {@link #uploadedImagesPath}
	 * 
	 * @return Valor de tipo String del campo {@link #uploadedImagesPath}
	 */
	public String getUploadedImagesPath() {
		return this.uploadedImagesPath;
	}

	/**
	 * Devuelve el valor del campo {@link #displayImagesPath}
	 * 
	 * @return Valor de tipo String del campo {@link #displayImagesPath}
	 */
	public String getDisplayImagesPath() {
		return this.displayImagesPath;
	}
}
