package edu.uoc.recetario.struts2;

import java.sql.SQLException;
import java.util.Map;

import org.apache.struts2.interceptor.SessionAware;

import com.opensymphony.xwork2.ActionSupport;
import com.opensymphony.xwork2.ModelDriven;

import edu.uoc.recetario.arquitectura.messages.Message;
import edu.uoc.recetario.arquitectura.pojo.UsuarioPojo;
import edu.uoc.recetario.cu00.CU00Script;
import edu.uoc.recetario.cu00.CU01Model;

/**
 * Clase que implementa la parte Controlador del caso de uso CU01 (login)
 * 
 * @author Jorge Puig de la Bellacasa
 * 
 */
public class CU01 extends ActionSupport implements ModelDriven<CU01Model>,
		SessionAware {

	/** serialVersionUID */
	private static final long serialVersionUID = -7071589020109998281L;
	/** modelo */
	private final CU01Model model = new CU01Model();
	/** sesin */
	private Map<String, Object> session;

	/**
	 * (non-Javadoc)
	 * 
	 * @see com.opensymphony.xwork2.ActionSupport#execute()
	 */
	@Override
	public String execute() {
		String r = "failure";
		try {
			UsuarioPojo p = CU00Script.autentificar(getModel());
			if (p != null) {
				this.session.put("usuario", p);
				r = "success";
			} else {
				Message m = new Message();
				m.setTipo(Message.Type.INFO);
				m.setMensaje("El usuario introducido no existe o la contrasea es incorrecta");
				this.model.getMessages().add(m);
				r = "failure";
			}
		} catch (SQLException e) {
			Message m = new Message();
			m.setTipo(Message.Type.ERROR);
			m.setMensaje("Se ha producido un error en el acceso a la base de datos"
					+ e.getMessage());
			this.model.getMessages().add(m);
			return "error";
		} catch (Exception e) {
			Message m = new Message();
			m.setTipo(Message.Type.ERROR);
			m.setMensaje("Se ha producido un error" + e.getMessage());
			this.model.getMessages().add(m);
			return "error";
		}
		return r;

	}

	/**
	 * (non-Javadoc)
	 * 
	 * @see com.opensymphony.xwork2.ModelDriven#getModel()
	 */
	@Override
	public CU01Model getModel() {
		return this.model;
	}

	/**
	 * (non-Javadoc)
	 * 
	 * @see com.opensymphony.xwork2.ActionSupport#validate()
	 */
	@Override
	public void validate() {

		if (getModel().getUsuario().getId().length() == 0) {
			addFieldError("usuario.id", "introduzca su usuario");
		}
		if (getModel().getUsuario().getId().length() > 15) {
			addFieldError("usuario.id",
					"el usuario introducido es demasiado largo");
		}
		if (getModel().getUsuario().getContrasena().length() == 0) {
			addFieldError("usuario.contrasena", "introduzca su contrasea");
		}
		if (getModel().getUsuario().getContrasena().length() > 15) {
			addFieldError("usuario.contrasena",
					"la contrasea introducida es demasiado larga");
		}
		UsuarioPojo p;
		try {
			p = CU00Script.autentificar(getModel());
			if (p == null) {
				addFieldError("usuario.id",
						"el usuario no existe o la contrasea es incorrecta");
			}
		} catch (SQLException e) {
			addFieldError("usuario.id",
					"se ha producido un error en el acceso a la base de datos");
		} catch (Exception e) {
			addFieldError("usuario.id", "se ha producido un error desconocido");
		}
	}

	/**
	 * (non-Javadoc)
	 * 
	 * @see org.apache.struts2.interceptor.SessionAware#setSession(java.util.Map)
	 */
	@Override
	public void setSession(Map<String, Object> session) {
		this.session = session;
	}

}
