package edu.uoc.recetario.struts2;

import java.sql.SQLException;
import java.util.Map;
import java.util.regex.Pattern;

import org.apache.struts2.interceptor.SessionAware;

import com.opensymphony.xwork2.ActionSupport;
import com.opensymphony.xwork2.ModelDriven;

import edu.uoc.recetario.arquitectura.messages.Message;
import edu.uoc.recetario.arquitectura.pojo.UsuarioPojo;
import edu.uoc.recetario.cu00.CU00Script;
import edu.uoc.recetario.cu00.CU02Model;

/**
 * Clase que implementa la parte Controlador del caso de uso CU02 (registrar
 * usuario)
 * 
 * @author Jorge
 * 
 */
public class CU02 extends ActionSupport implements ModelDriven<CU02Model>,
		SessionAware {

	/** serialVersionUID */
	private static final long serialVersionUID = -5626091443903827384L;
	/** modelo */
	private final CU02Model model = new CU02Model();
	/** sesin */
	private Map<String, Object> session;
	/** patrn para comprobar usuario y password */
	static Pattern userYPassPattern = Pattern
			.compile("^[a-zA-Z0-9]+$");
	/** patrn para comprobar e-mail vlidos */
	static Pattern emailPattern = Pattern
			.compile("^[a-z0-9!#$%&'*+/=?^_`{|}~-]+(?:\\.[a-z0-9!#$%&'*+/=?^_`{|}~-]+)*@(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?$");

	/**
	 * (non-Javadoc)
	 * 
	 * @see com.opensymphony.xwork2.ActionSupport#execute()
	 */
	@Override
	public String execute() {
		String r = "failure";
		try {
			UsuarioPojo p = CU00Script.crearUsuario(this.model);
			if (p != null) {
				this.session.put("usuario", p);
				r = "success";
			}
		} catch (SQLException e) {
			Message m = new Message();
			m.setTipo(Message.Type.ERROR);
			m.setMensaje("Se ha producido un error en el acceso a la base de datos"
					+ e.getMessage());
			this.model.getMessages().add(m);
			return "error";
		} catch (Exception e) {
			Message m = new Message();
			m.setTipo(Message.Type.ERROR);
			m.setMensaje("Se ha producido un error" + e.getMessage());
			this.model.getMessages().add(m);
			return "error";
		}
		return r;
	}

	/**
	 * (non-Javadoc)
	 * 
	 * @see com.opensymphony.xwork2.ModelDriven#getModel()
	 */
	@Override
	public CU02Model getModel() {
		return this.model;
	}

	/**
	 * (non-Javadoc)
	 * 
	 * @see com.opensymphony.xwork2.ActionSupport#validate()
	 */
	@Override
	public void validate() {

		if (getModel().getUsuario().length() < 6) {
			addFieldError("usuario",
					"el identificador de usuario es demasiado corto");
		} else if (getModel().getContrasena().length() < 6) {
			addFieldError("contrasena", "contrasea demasiado corta");
		}
		if (getModel().getUsuario().length() > 15) {
			addFieldError("usuario",
					"el identificador de usuario es demasiado largo");
		} else if (getModel().getContrasena().length() > 15) {
			addFieldError("contrasena", "la contrasea es demasiado larga");
		} else if (getModel().getReContrasena().length() == 0) {
			addFieldError("reContrasena", "por favor repita su contrasea");
		} else if (!getModel().getReContrasena().equals(
				getModel().getContrasena())) {
			addFieldError("reContrasena", "las contraseas no coinciden");
		} else if (getModel().getEmail().length() == 0) {
			addFieldError("email", "introduzca su email");
		} else if (getModel().getReEmail().length() == 0) {
			addFieldError("reEmail", "por favor repita su e-mail");
		} else if (getModel().getEmail().length() > 45) {
			addFieldError("email", "el e-mail introducido es demasiado largo");
		} else if (!getModel().getReEmail().equals(getModel().getEmail())) {
			addFieldError("reEmail", "los e-mail no coinciden");
		} else if (!userYPassPattern.matcher(getModel().getUsuario()).matches()) {
			addFieldError("usuario", "por favor, use los caracteres permitidos");
		} else if (!userYPassPattern.matcher(getModel().getContrasena())
				.matches()) {
			addFieldError("contrasena",
					"por favor, use los caracteres permitidos");
		} else if (!emailPattern.matcher(getModel().getEmail()).matches()) {
			addFieldError("email", "introduzca una direccin de e-mail vlida");
		}
		try {
			if (CU00Script.userExists(getModel())) {
				addFieldError("usuario", "ya existe un usuario con este nombre");
			}
		} catch (Throwable e) {
			// exception ignore
		}

	}

	/**
	 * (non-Javadoc)
	 * 
	 * @see org.apache.struts2.interceptor.SessionAware#setSession(java.util.Map)
	 */
	@Override
	public void setSession(Map<String, Object> session) {
		this.session = session;
	}

}
