/**
 * Copyright (c) 2013 Jorge Puig de la Bellacasa
 * Licencia GNU
 */
package edu.uoc.recetario.struts2;

import java.sql.SQLException;
import java.util.Map;
import java.util.regex.Pattern;

import org.apache.struts2.interceptor.SessionAware;

import com.opensymphony.xwork2.ActionSupport;
import com.opensymphony.xwork2.ModelDriven;

import edu.uoc.recetario.arquitectura.messages.Message;
import edu.uoc.recetario.arquitectura.pojo.UsuarioPojo;
import edu.uoc.recetario.gc00.GC00Model;
import edu.uoc.recetario.gc00.GC00Script;

/**
 * Clase que implementa la parte Controlador del caso de uso GC02 (cambiar datos
 * de usuario)
 * 
 * @author Jorge Puig de la Bellacasa
 * 
 */
public class GC02 extends ActionSupport implements ModelDriven<GC00Model>,
		SessionAware {

	/** serialVersionUID */
	private static final long serialVersionUID = 821833521580402528L;
	/** modelo */
	private final GC00Model model = new GC00Model();
	/** sesin */
	private Map<String, Object> session;
	/** patrn para comprobar usuario y password */
	static Pattern userYPassPattern = Pattern
			.compile("^[a-zA-Z0-9]+$");
	/** patrn para comprobar e-mail vlidos */
	static Pattern emailPattern = Pattern
			.compile("^[a-z0-9!#$%&'*+/=?^_`{|}~-]+(?:\\.[a-z0-9!#$%&'*+/=?^_`{|}~-]+)*@(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?$");

	/**
	 * (non-Javadoc)
	 * 
	 * @see com.opensymphony.xwork2.ActionSupport#execute()
	 */
	@Override
	public String execute() {
		String r = "failure";
		UsuarioPojo usuarioNuevosDatos = null;
		try {
			if (this.session.containsKey("usuario")) {
				this.model.setUsuarioSesion((UsuarioPojo) this.session
						.get("usuario"));
				if (GC00Script.autentificar(this.model)) {
					usuarioNuevosDatos = GC00Script.cambiarDatos(this.model);
					if (usuarioNuevosDatos != null) {
						this.session.clear();
						this.session.put("usuario",
								this.model.getUsuarioSesion());
						Message m = new Message();
						m.setTipo(Message.Type.INFO);
						m.setMensaje("se han cambiado correctamente los datos de usuario");
						this.model.getMessages().add(m);
						r = "success";
					} else {
						Message m = new Message();
						m.setTipo(Message.Type.ERROR);
						m.setMensaje("el usuario no existe, parece que han borrado su cuenta");
						this.model.getMessages().add(m);
						r = "error";
					}
				} else {
					Message m = new Message();
					m.setTipo(Message.Type.INFO);
					m.setMensaje("la contrasea introducida no es correcta, por favor vuelva a intentarlo");
					this.model.getMessages().add(m);
					r = "failure";
				}

			} else {
				r = "login";
			}
		} catch (SQLException e) {
			Message m = new Message();
			m.setTipo(Message.Type.ERROR);
			m.setMensaje("Se ha producido un error en el acceso a la base de datos"
					+ e.getMessage());
			this.model.getMessages().add(m);
			return "error";
		} catch (Exception e) {
			Message m = new Message();
			m.setTipo(Message.Type.ERROR);
			m.setMensaje("Se ha producido un error" + e.getMessage());
			this.model.getMessages().add(m);
			System.out.println(e.toString());
			return "error";
		}
		return r;
	}

	/**
	 * (non-Javadoc)
	 * 
	 * @see com.opensymphony.xwork2.ActionSupport#validate()
	 */
	@Override
	public void validate() {

		if (getModel().getContrasena().length() < 6) {
			addFieldError("contrasena", "introduzca su contrasea actual");
		} else if (getModel().getNuevaContrasena().length() > 0) {
			if (getModel().getNuevaContrasena().length() > 15) {
				addFieldError("nuevaContrasena",
						"la nueva contrasea es demasiado larga");
			} else if (getModel().getNuevaContrasena().length() < 6) {
				addFieldError("nuevaContrasena",
						"la nueva contrasea es demasiado corta");
			} else if (getModel().getReNuevaContrasena().length() == 0) {
				addFieldError("reNuevaContrasena",
						"por favor repita su nueva contrasea");
			} else if (!getModel().getReNuevaContrasena().equals(
					getModel().getNuevaContrasena())) {
				addFieldError("reNuevaContrasena",
						"las contraseas no coinciden");
			} else if (!userYPassPattern.matcher(
					getModel().getNuevaContrasena()).matches()) {
				addFieldError("contrasena",
						"por favor, use los caracteres permitidos");
			}
		} else if (getModel().getNuevoEmail().length() > 0) {
			if (!emailPattern.matcher(getModel().getNuevoEmail()).matches()) {
				addFieldError("nuevoEmail",
						"introduzca una direccin de e-mail vlida");
			} else if (!getModel().getReNuevoEmail().equals(
					getModel().getNuevoEmail())) {
				addFieldError("reNuevoEmail",
						"las direcciones de e-mail no coinciden");
			}
		}
	}

	/**
	 * (non-Javadoc)
	 * 
	 * @see org.apache.struts2.interceptor.SessionAware#setSession(java.util.Map)
	 */
	@Override
	public void setSession(Map<String, Object> session) {
		this.session = session;
	}

	/**
	 * (non-Javadoc)
	 * 
	 * @see com.opensymphony.xwork2.ModelDriven#getModel()
	 */
	@Override
	public GC00Model getModel() {
		return this.model;
	}

}
