package edu.uoc.recetario.struts2;

import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Map;

import org.apache.struts2.interceptor.SessionAware;
import org.owasp.esapi.ESAPI;

import com.opensymphony.xwork2.ActionSupport;
import com.opensymphony.xwork2.ModelDriven;

import edu.uoc.recetario.arquitectura.messages.Message;
import edu.uoc.recetario.arquitectura.pojo.ComentarioPojo;
import edu.uoc.recetario.arquitectura.pojo.RecetaPojo;
import edu.uoc.recetario.arquitectura.pojo.UsuarioPojo;
import edu.uoc.recetario.gr00.GR00Model;
import edu.uoc.recetario.gr00.GR00Script;

/**
 * Clase que implementa la parte Controlador de los casos de uso del grupo
 * funcional GR00 (administrar recetas)
 * 
 * @author Jorge Puig de la Bellacasa
 * 
 */
public class GR00 extends ActionSupport implements ModelDriven<GR00Model>,
		SessionAware {

	/** serialVersionUID */
	private static final long serialVersionUID = 8434816780473754216L;
	/** modelo */
	private final GR00Model model = new GR00Model();
	/** sesin */
	private Map<String, Object> session;

	/**
	 * (non-Javadoc)
	 * 
	 * @see com.opensymphony.xwork2.ActionSupport#execute()
	 */
	@Override
	public String execute() {
		String r = "failure";
		try {
			if (this.session.containsKey("usuario")) {
				this.model.setUsuarioSesion((UsuarioPojo) this.session
						.get("usuario"));
				String accion = this.model.getAccionSolicitada();
				if (accion.equals("1")) {
					this.model.setReceta(new RecetaPojo());
					this.model.getReceta().setNombreReceta(
							this.model.getNombre());
					Collection<RecetaPojo> listaRecetas = GR00Script
							.buscarRecetas(this.model);
					if (listaRecetas != null) {
						this.model.setRecetas(listaRecetas);
						r = "success";
					} else {
						Message m = new Message();
						m.setTipo(Message.Type.INFO);
						m.setMensaje("no se ha encontrado ninguna receta con el nombre introducido");
						this.model.getMessages().add(m);
						r = "failure";
					}
				} else if (accion.equals("2")) {
					this.model.setUsuario(new UsuarioPojo());
					this.model.getUsuario().setId(this.model.getNombre());
					Collection<RecetaPojo> listaRecetas = GR00Script
							.buscarRecetasUsuario(this.model);
					if (listaRecetas != null) {
						this.model.setRecetas(listaRecetas);
						r = "success";
					} else {
						Message m = new Message();
						m.setTipo(Message.Type.INFO);
						m.setMensaje("no se ha encontrado ninguna receta perteneciente al usuario introducido");
						this.model.getMessages().add(m);
						r = "failure";
					}
				} else {
					Message m = new Message();
					m.setTipo(Message.Type.INFO);
					m.setMensaje("no se ha cargado la solicitud");
					this.model.getMessages().add(m);
					r = "failure";
				}
			} else {
				r = "login";
			}
		} catch (SQLException e) {
			Message m = new Message();
			m.setTipo(Message.Type.ERROR);
			m.setMensaje("Se ha producido un error en el acceso a la base de datos"
					+ e.getMessage());
			this.model.getMessages().add(m);
			return "error";
		} catch (Exception e) {
			Message m = new Message();
			m.setTipo(Message.Type.ERROR);
			m.setMensaje("Se ha producido un error" + e.getMessage());
			this.model.getMessages().add(m);
			System.out.println(e.toString());
			return "error";
		}
		return r;
	}

	/**
	 * recupera la receta y sus comentarios segn los datos del modelo
	 * 
	 * @return "success" si la receta existe, "failure" si no, "error" si se
	 *         producen excepciones
	 */
	public String mostrar() {
		String r = "failure";
		try {
			this.model.setReceta(GR00Script.loadReceta(this.model));
			if (this.model.getReceta() != null) {
				this.model.setComentarios(GR00Script
						.buscarComentarios(this.model));
				if (this.model.getComentarios() == null) {
					this.model.setComentarios(new ArrayList<ComentarioPojo>());
				}
				for (ComentarioPojo c : this.model.getComentarios()) {
					c.setTexto(ESAPI.encoder().encodeForHTML(c.getTexto()));
				}
				this.model.getReceta().setNombreReceta(
						ESAPI.encoder().encodeForHTMLAttribute(
								this.model.getReceta().getNombreReceta()));
				this.model.getReceta().setIngredientes(
						ESAPI.encoder().encodeForHTML(
								this.model.getReceta().getIngredientes()));
				this.model.getReceta().setPreparacion(
						ESAPI.encoder().encodeForHTML(
								this.model.getReceta().getPreparacion()));
				//
				// this.model.getReceta().setIngredientes(ESAPI...
				r = "success";
			} else {
				Message m = new Message();
				m.setTipo(Message.Type.INFO);
				m.setMensaje("La receta no existe");
				this.model.getMessages().add(m);
			}
		} catch (SQLException e) {
			Message m = new Message();
			m.setTipo(Message.Type.ERROR);
			m.setMensaje("Se ha producido un error en el acceso a la base de datos"
					+ e.getMessage());
			this.model.getMessages().add(m);
			return "error";
		} catch (Exception e) {
			Message m = new Message();
			m.setTipo(Message.Type.ERROR);
			m.setMensaje("Se ha producido un error" + e.getMessage());
			this.model.getMessages().add(m);
			System.out.println(e.toString());
			return "error";
		}
		return r;
	}

	/**
	 * Mtodo que crea una receta
	 * 
	 * @return "success" si se ha creado la receta, "failure" si no, "error" si
	 *         se han producido excepciones
	 */
	public String crearReceta() {
		String r = "failure";
		try {
			if (this.session.containsKey("usuario")) {
				this.model.setUsuarioSesion((UsuarioPojo) this.session
						.get("usuario"));
				RecetaPojo receta = GR00Script.crearReceta(this.model);
				if (receta != null) {
					this.model.setReceta(receta);
					this.model.setComentarios(new ArrayList<ComentarioPojo>());
					r = "success";
				} else {
					Message m = new Message();
					m.setTipo(Message.Type.INFO);
					m.setMensaje("error desconocido al crear la receta");
					this.model.getMessages().add(m);
					r = "failure";
				}
			} else {
				r = "login";
			}
		} catch (SQLException e) {
			Message m = new Message();
			m.setTipo(Message.Type.ERROR);
			m.setMensaje("Se ha producido un error en el acceso a la base de datos"
					+ e.getMessage());
			this.model.getMessages().add(m);
			return "error";
		} catch (Exception e) {
			Message m = new Message();
			m.setTipo(Message.Type.ERROR);
			m.setMensaje("Se ha producido un error" + e.getMessage());
			this.model.getMessages().add(m);
			System.out.println(e.toString());
			return "error";
		}
		return r;
	}

	/**
	 * Mtodo que crea un comentario
	 * 
	 * @return "success" si se ha creado el comentario, "failure" si no, "error"
	 *         si se han producido excepciones
	 */
	public String nuevoComentario() {
		String r = "failure";
		try {
			if (this.session.containsKey("usuario")) {
				this.model.setUsuarioSesion((UsuarioPojo) this.session
						.get("usuario"));
				if (this.model.getComentario().getIdReceta() != null) {
					this.model.setReceta(new RecetaPojo());
					this.model.getReceta().setId(
							this.model.getComentario().getIdReceta());
					this.model.setReceta(GR00Script.loadReceta(this.model));
					if (this.model.getReceta() != null) {
						this.model.setComentario(GR00Script
								.nuevoComentario(this.model));
						if (this.model.getComentario() != null) {
							this.model.setComentarios(GR00Script
									.buscarComentarios(this.model));
							r = "success";
						} else {
							Message m = new Message();
							m.setTipo(Message.Type.INFO);
							m.setMensaje("se ha producido un error desconocido al crear el comentario");
							this.model.getMessages().add(m);
						}
					} else {
						Message m = new Message();
						m.setTipo(Message.Type.INFO);
						m.setMensaje("la receta no existe");
						this.model.getMessages().add(m);
					}
				} else {
					Message m = new Message();
					m.setTipo(Message.Type.INFO);
					m.setMensaje("no se ha cargado el identificador de receta en el comentario");
					this.model.getMessages().add(m);
				}
			} else {
				r = "login";
			}
		} catch (SQLException e) {
			Message m = new Message();
			m.setTipo(Message.Type.ERROR);
			m.setMensaje("Se ha producido un error en el acceso a la base de datos"
					+ e.getMessage());
			this.model.getMessages().add(m);
			return "error";
		} catch (Exception e) {
			Message m = new Message();
			m.setTipo(Message.Type.ERROR);
			m.setMensaje("Se ha producido un error" + e.getMessage());
			this.model.getMessages().add(m);
			System.out.println(e.toString());
			return "error";
		}
		return r;
	}

	/**
	 * Mtodo que elimina un comentario
	 * 
	 * @return "success" si se ha eliminado el comentario, "failure" si no,
	 *         "error" si se han producido excepciones
	 */
	public String eliminarComentario() {
		String r = "failure";
		try {
			if (this.session.containsKey("usuario")) {
				this.model.setUsuarioSesion((UsuarioPojo) this.session
						.get("usuario"));
				if (this.model.getComentario().getId() != null
						&& this.model.getReceta().getId() != null) {
					this.model.setComentario(GR00Script
							.loadComentario(this.model));
					this.model.setReceta(GR00Script.loadReceta(this.model));
					if (this.model.getReceta() != null
							&& this.model.getComentario() != null) {
						if (this.model.getUsuarioSesion().getTipoUsuario()
								.equals("admin")
								|| this.model
										.getUsuarioSesion()
										.getId()
										.equals(this.model.getComentario()
												.getIdUsuario())) {
							GR00Script.eliminarComentario(this.model);
							this.model.setComentarios(GR00Script
									.buscarComentarios(this.model));
							if (this.model.getComentarios() == null) {
								this.model
										.setComentarios(new ArrayList<ComentarioPojo>());
							}
							r = "success";
						} else {
							Message m = new Message();
							m.setTipo(Message.Type.INFO);
							m.setMensaje("solo los usuarios administradores pueden eliminar comentarios de otros usuarios");
							this.model.getMessages().add(m);
						}
					} else {
						Message m = new Message();
						m.setTipo(Message.Type.INFO);
						m.setMensaje("el comentario o la receta no existen");
						this.model.getMessages().add(m);
					}
				} else {
					Message m = new Message();
					m.setTipo(Message.Type.INFO);
					m.setMensaje("no se han cargado los identificadores de comentario y/o receta");
					this.model.getMessages().add(m);
				}
			} else {
				r = "login";
			}
		} catch (SQLException e) {
			Message m = new Message();
			m.setTipo(Message.Type.ERROR);
			m.setMensaje("Se ha producido un error en el acceso a la base de datos"
					+ e.getMessage());
			this.model.getMessages().add(m);
			return "error";
		} catch (Exception e) {
			Message m = new Message();
			m.setTipo(Message.Type.ERROR);
			m.setMensaje("Se ha producido un error" + e.getMessage());
			this.model.getMessages().add(m);
			System.out.println(e.toString());
			return "error";
		}
		return r;
	}

	/**
	 * Elimina la foto de esta receta
	 * 
	 * @return "success" si se ha eliminado la foto, "info" si no se ha
	 *         eliminado, "error" si se han producido errores
	 * 
	 */
	public String eliminarFoto() {
		String r = "failure";
		try {
			if (this.session.containsKey("usuario")) {
				this.model.setUsuarioSesion((UsuarioPojo) this.session
						.get("usuario"));
				if (this.model.getReceta() != null) {
					if (this.model.getReceta().getId() != null) {
						this.model.setReceta(GR00Script.loadReceta(this.model));
						if (this.model.getReceta() != null) {
							if (this.model.getUsuarioSesion().getTipoUsuario()
									.equals("admin")
									|| this.model
											.getUsuarioSesion()
											.getId()
											.equals(this.model.getReceta()
													.getIdUsuario())) {
								this.model.setReceta(GR00Script
										.eliminarFoto(this.model));
								if (this.model.getReceta() != null) {
									this.model.setComentarios(GR00Script
											.buscarComentarios(this.model));
									if (this.model.getComentarios() == null) {
										this.model
												.setComentarios(new ArrayList<ComentarioPojo>());
									}
									r = "success";
								} else {
									Message m = new Message();
									m.setTipo(Message.Type.INFO);
									m.setMensaje("la fotografa no existe");
									this.model.getMessages().add(m);
								}

							} else {
								Message m = new Message();
								m.setTipo(Message.Type.INFO);
								m.setMensaje("solo los usuarios administradores pueden eliminar fotografas de otros usuarios");
								this.model.getMessages().add(m);
							}
						} else {
							Message m = new Message();
							m.setTipo(Message.Type.INFO);
							m.setMensaje("la receta no existe");
							this.model.getMessages().add(m);
						}
					} else {
						Message m = new Message();
						m.setTipo(Message.Type.INFO);
						m.setMensaje("no se ha cargado el identificador de receta");
						this.model.getMessages().add(m);
					}
				} else {
					Message m = new Message();
					m.setTipo(Message.Type.INFO);
					m.setMensaje("no se ha cargado el identificador de receta");
					this.model.getMessages().add(m);
				}
			} else {
				r = "login";
			}
		} catch (SQLException e) {
			Message m = new Message();
			m.setTipo(Message.Type.ERROR);
			m.setMensaje("Se ha producido un error en el acceso a la base de datos"
					+ e.getMessage());
			this.model.getMessages().add(m);
			return "error";
		} catch (Exception e) {
			Message m = new Message();
			m.setTipo(Message.Type.ERROR);
			m.setMensaje("Se ha producido un error" + e.getMessage());
			this.model.getMessages().add(m);
			System.out.println(e.toString());
			return "error";
		}
		return r;
	}

	/**
	 * Elimina la receta junto con sus comentarios y fotografa
	 * 
	 * @return "success" si se ha eliminado la receta, "failure" si no, "error"
	 *         si se han producido errores
	 */

	public String eliminarReceta() {
		String r = "failure";
		try {
			if (this.session.containsKey("usuario")) {
				this.model.setUsuarioSesion((UsuarioPojo) this.session
						.get("usuario"));
				if (this.model.getReceta() != null) {
					if (this.model.getReceta().getId() != null) {
						this.model.setReceta(GR00Script.loadReceta(this.model));
						if (this.model.getReceta() != null) {
							if (this.model.getUsuarioSesion().getTipoUsuario()
									.equals("admin")
									|| this.model
											.getUsuarioSesion()
											.getId()
											.equals(this.model.getReceta()
													.getIdUsuario())) {
								if (GR00Script.eliminarReceta(this.model)) {
									Message m = new Message();
									m.setTipo(Message.Type.INFO);
									m.setMensaje("la receta se ha eliminado correctamente");
									this.model.getMessages().add(m);
									r = "success";
								} else {
									Message m = new Message();
									m.setTipo(Message.Type.ERROR);
									m.setMensaje("la receta se ha eliminado correctamente");
									this.model.getMessages().add(m);
								}
							} else {
								Message m = new Message();
								m.setTipo(Message.Type.INFO);
								m.setMensaje("solo los usuarios administradores pueden eliminar recetas de otros usuarios");
								this.model.getMessages().add(m);
							}
						} else {
							Message m = new Message();
							m.setTipo(Message.Type.INFO);
							m.setMensaje("la receta no existe");
							this.model.getMessages().add(m);
						}
					} else {
						Message m = new Message();
						m.setTipo(Message.Type.INFO);
						m.setMensaje("no se ha cargado el identificador de receta");
						this.model.getMessages().add(m);
					}
				} else {
					Message m = new Message();
					m.setTipo(Message.Type.INFO);
					m.setMensaje("no se ha cargado el identificador de receta");
					this.model.getMessages().add(m);
				}
			} else {
				r = "login";
			}
		} catch (SQLException e) {
			Message m = new Message();
			m.setTipo(Message.Type.ERROR);
			m.setMensaje("Se ha producido un error en el acceso a la base de datos"
					+ e.getMessage());
			this.model.getMessages().add(m);
			return "error";
		} catch (Exception e) {
			Message m = new Message();
			m.setTipo(Message.Type.ERROR);
			m.setMensaje("Se ha producido un error" + e.getMessage());
			this.model.getMessages().add(m);
			System.out.println(e.toString());
			return "error";
		}
		return r;
	}

	/**
	 * Modifica una receta
	 * 
	 * @return "success" si se ha modificado la receta, "failure" si no, "error"
	 *         si se han producido errores
	 */
	public String modificarReceta() {
		String r = "failure";
		try {
			if (this.session.containsKey("usuario")) {
				this.model.setUsuarioSesion((UsuarioPojo) this.session
						.get("usuario"));
				if (this.model.getReceta().getIdUsuario() != null) {
					if (this.model.getReceta().getIdUsuario()
							.equals(this.model.getUsuarioSesion().getId())
							|| this.model.getUsuarioSesion().getTipoUsuario()
									.equals("admin")) {
						RecetaPojo receta = GR00Script
								.modificarReceta(this.model);
						if (receta != null) {
							this.model.setReceta(receta);
							this.model
									.setComentarios(new ArrayList<ComentarioPojo>());
							r = "success";
						} else {
							Message m = new Message();
							m.setTipo(Message.Type.INFO);
							m.setMensaje("error desconocido al crear la receta");
							this.model.getMessages().add(m);
							r = "failure";
						}
					} else {
						Message m = new Message();
						m.setTipo(Message.Type.INFO);
						m.setMensaje("solo los usuarios administradores pueden modificar recetas de otros usuarios");
						this.model.getMessages().add(m);
						r = "failure";
					}
				} else {
					Message m = new Message();
					m.setTipo(Message.Type.INFO);
					m.setMensaje("no se ha cargado el identificador de usuario de la receta");
					this.model.getMessages().add(m);
					r = "failure";
				}
			} else {
				r = "login";
			}
		} catch (SQLException e) {
			Message m = new Message();
			m.setTipo(Message.Type.ERROR);
			m.setMensaje("Se ha producido un error en el acceso a la base de datos"
					+ e.getMessage());
			this.model.getMessages().add(m);
			return "error";
		} catch (Exception e) {
			Message m = new Message();
			m.setTipo(Message.Type.ERROR);
			e.printStackTrace();
			m.setMensaje("Se ha producido un error" + e.getMessage());
			this.model.getMessages().add(m);
			System.out.println(e.toString());
			return "error";
		}
		return r;
	}

	/**
	 * (non-Javadoc)
	 * 
	 * @see com.opensymphony.xwork2.ActionSupport#validate()
	 */
	@Override
	public void validate() {

		String accion = this.model.getAccionSolicitada();
		if (accion != null) {
			if (accion.equals("1") || accion.equals("2")) {
				if (getModel().getNombre().length() == 0) {
					addFieldError("nombre", "introduzca un trmino de bsqueda");
				}
			}
			if (accion.equals("crear receta")
					|| accion.equals("modificar receta")) {
				if (this.model.getReceta().getNombreReceta().length() == 0) {
					addFieldError("receta.nombreReceta",
							"introduzca un nombre de receta");
				}
				if (this.model.getReceta().getIngredientes().length() == 0) {
					addFieldError("receta.ingredientes",
							"introduzca los ingredientes");
				}
				if (this.model.getReceta().getPreparacion().length() == 0) {
					addFieldError("receta.preparacion",
							"introduzca el mtodo de preparacin");
				}
				if (this.model.getReceta().getComensales() <= 0) {
					addFieldError("receta.comensales",
							"el nmero de comensales debe ser un entero mayor de 0");
				}
			}
			if (accion.equals("nuevo comentario")) {
				if (this.model.getComentario().getTexto().length() == 0) {
					addFieldError("comentario.texto",
							"introduzca un comentario");
				}
			}
		}
	}

	/**
	 * (non-Javadoc)
	 * 
	 * @see org.apache.struts2.interceptor.SessionAware#setSession(java.util.Map)
	 */
	@Override
	public void setSession(Map<String, Object> session) {
		this.session = session;
	}

	/**
	 * (non-Javadoc)
	 * 
	 * @see com.opensymphony.xwork2.ModelDriven#getModel()
	 */
	@Override
	public GR00Model getModel() {
		return this.model;
	}

}
