/**
 * Copyright (c) 2013 Jorge Puig de la Bellacasa
 * Licencia GNU
 */
package edu.uoc.recetario.struts2;

import java.sql.SQLException;
import java.util.Map;

import org.apache.struts2.interceptor.SessionAware;

import com.opensymphony.xwork2.ActionSupport;
import com.opensymphony.xwork2.ModelDriven;

import edu.uoc.recetario.arquitectura.messages.Message;
import edu.uoc.recetario.arquitectura.pojo.UsuarioPojo;
import edu.uoc.recetario.gs00.GS00Model;
import edu.uoc.recetario.gs00.GS00Script;

/**
 * Implementa la parte controlador del grupo funcional GS00 (gestin del
 * sistema)
 * 
 * @author Jorge
 * 
 */
public class GS00 extends ActionSupport implements ModelDriven<GS00Model>,
		SessionAware {

	/** TODO JAVADOC serialVersionUID */
	private static final long serialVersionUID = 7451263477401454014L;
	/** modelo */
	private final GS00Model model = new GS00Model();
	/** sesin */
	private Map<String, Object> session;

	/** patrn para comprobar usuario y password */

	/**
	 * (non-Javadoc)
	 * 
	 * @see com.opensymphony.xwork2.ActionSupport#execute()
	 */
	@Override
	public String execute() {
		String r = "failure";
		try {
			if (this.session.containsKey("usuario")) {
				this.model.setUsuarioSesion((UsuarioPojo) this.session
						.get("usuario"));
				if (this.model.getUsuarioSesion().getTipoUsuario()
						.equals("admin")) {
					this.model.setUsuario(GS00Script.loadUsuario(this.model));
					if (this.model.getUsuario() != null) {
						r = "success";
					} else {
						Message m = new Message();
						m.setTipo(Message.Type.INFO);
						m.setMensaje("No existe ningn usuario con el identificador introducido, compruebe maysculas, minsculas y tildes");
						this.model.getMessages().add(m);
					}
				} else {
					Message m = new Message();
					m.setTipo(Message.Type.INFO);
					m.setMensaje("Solo los usuarios administradores tienen acceso a esta funcin del sistema");
					this.model.getMessages().add(m);
				}
			} else {
				r = "login";
			}
		} catch (SQLException e) {
			Message m = new Message();
			m.setTipo(Message.Type.ERROR);
			m.setMensaje("Se ha producido un error en el acceso a la base de datos"
					+ e.getMessage());
			this.model.getMessages().add(m);
			return "error";
		} catch (Exception e) {
			Message m = new Message();
			m.setTipo(Message.Type.ERROR);
			m.setMensaje("Se ha producido un error" + e.getMessage());
			this.model.getMessages().add(m);
			System.out.println(e.toString());
			return "error";
		}
		return r;
	}

	/**
	 * Modifica el usuario segn la solicitud almacenada en el modelo (borrar o
	 * promocionar)
	 * 
	 * @return "success" si se han realizado los cambios con xito. "failure" de
	 *         lo contrario. "error" si se han producido excepciones
	 */
	public String modificarUsuario() {
		String r = "failure";
		try {
			if (this.session.containsKey("usuario")) {
				this.model.setUsuarioSesion((UsuarioPojo) this.session
						.get("usuario"));
				if (this.model.getUsuarioSesion().getTipoUsuario()
						.equals("admin")) {
					if (this.model.getUsuario().getId() != null) {
						this.model.setUsuario(GS00Script
								.loadUsuario(this.model));
						if (this.model.getUsuario() != null) {
							if (!this.model.getUsuario().getTipoUsuario()
									.equals("admin")) {
								if (this.model.getAccionSolicitada()
										.equals("1")) {
									boolean eliminado = GS00Script
											.eliminarUsuario(this.model);
									if (eliminado) {
										Message m = new Message();
										m.setTipo(Message.Type.INFO);
										m.setMensaje("el usuario se ha eliminado correctamente");
										this.model.getMessages().add(m);
										r = "success";
									} else {
										Message m = new Message();
										m.setTipo(Message.Type.INFO);
										m.setMensaje("el usuario no se ha podido eliminar. Fallo desconocido");
										this.model.getMessages().add(m);
									}
								} else if (this.model.getAccionSolicitada()
										.equals("2")) {
									UsuarioPojo p = GS00Script
											.promocionarUsuario(this.model);
									if (p != null) {
										Message m = new Message();
										m.setTipo(Message.Type.INFO);
										m.setMensaje("el usuario se ha promocionado correctamente. Ahora "
												+ p.getId()
												+ " es usuario administrador");
										this.model.getMessages().add(m);
										r = "success";
									} else {
										Message m = new Message();
										m.setTipo(Message.Type.INFO);
										m.setMensaje("el usuario no se ha podido promocionar. Fallo desconocido");
										this.model.getMessages().add(m);
									}
								}
							} else {
								Message m = new Message();
								m.setTipo(Message.Type.INFO);
								m.setMensaje("el usuario que pretende modificar es administrador, no tiene permisos para modificar su cuenta. Contacte con el sysop si es necesario");
								this.model.getMessages().add(m);
							}
						} else {
							Message m = new Message();
							m.setTipo(Message.Type.INFO);
							m.setMensaje("el usuario no existe");
							this.model.getMessages().add(m);
						}
					} else {
						Message m = new Message();
						m.setTipo(Message.Type.INFO);
						m.setMensaje("no se ha cargado el identificador de usuario");
						this.model.getMessages().add(m);
					}
				} else {
					Message m = new Message();
					m.setTipo(Message.Type.INFO);
					m.setMensaje("Solo los usuarios administradores tienen acceso a esta funcin del sistema");
					this.model.getMessages().add(m);
				}
			} else {
				r = "login";
			}
		} catch (SQLException e) {
			Message m = new Message();
			m.setTipo(Message.Type.ERROR);
			m.setMensaje("Se ha producido un error en el acceso a la base de datos"
					+ e.getMessage());
			this.model.getMessages().add(m);
			return "error";
		} catch (Exception e) {
			Message m = new Message();
			m.setTipo(Message.Type.ERROR);
			m.setMensaje("Se ha producido un error" + e.getMessage());
			this.model.getMessages().add(m);
			System.out.println(e.toString());
			return "error";
		}
		return r;
	}

	/**
	 * (non-Javadoc)
	 * 
	 * @see com.opensymphony.xwork2.ActionSupport#validate()
	 */
	@Override
	public void validate() {
		if (this.model.getAccionSolicitada().equals("buscar usuario")
				&& this.model.getUsuario().getId().length() == 0) {
			addFieldError("usuario.id", "introduzca un trmino de bsqueda");
		}
	}

	/**
	 * (non-Javadoc)
	 * 
	 * @see org.apache.struts2.interceptor.SessionAware#setSession(java.util.Map)
	 */
	@Override
	public void setSession(Map<String, Object> session) {
		this.session = session;
	}

	/**
	 * (non-Javadoc)
	 * 
	 * @see com.opensymphony.xwork2.ModelDriven#getModel()
	 */
	@Override
	public GS00Model getModel() {
		return this.model;
	}

}
