package edu.uoc.recetario.struts2;

import java.sql.SQLException;
import java.util.Map;

import org.apache.struts2.interceptor.SessionAware;

import com.opensymphony.xwork2.ActionSupport;
import com.opensymphony.xwork2.ModelDriven;

import edu.uoc.recetario.arquitectura.messages.Message;
import edu.uoc.recetario.arquitectura.pojo.UsuarioPojo;
import edu.uoc.recetario.gr00.GR00Model;
import edu.uoc.recetario.gr00.GR00Script;

/**
 * Redirecciona al men de modificacin de receta si el usuario de esta sesin
 * es administrador y se han cargado los datos de la receta a modificar
 * 
 * @author Jorge Puig de la Bellacasa
 * 
 */
public class ToModificarReceta extends ActionSupport implements
		ModelDriven<GR00Model>, SessionAware {

	/** serialVersionUID */
	private static final long serialVersionUID = 7437170194543891571L;
	/** session */
	private Map<String, Object> session;
	/** model */
	private final GR00Model model = new GR00Model();

	/**
	 * (non-Javadoc)
	 * 
	 * @see com.opensymphony.xwork2.ActionSupport#execute()
	 */
	@Override
	public String execute() {
		String r = "failure";
		try {
			if (this.session.containsKey("usuario")) {
				this.model.setUsuarioSesion((UsuarioPojo) this.session
						.get("usuario"));
				if (this.model.getReceta() != null) {
					if (this.model.getReceta().getId() != null) {
						this.model.setReceta(GR00Script.loadReceta(this.model));
						if (this.model.getReceta() != null) {
							r = "success";
						} else {
							Message m = new Message();
							m.setTipo(Message.Type.INFO);
							m.setMensaje("la receta no existe");
							this.model.getMessages().add(m);
						}
					} else {
						Message m = new Message();
						m.setTipo(Message.Type.INFO);
						m.setMensaje("no se ha cargado el identificador de receta");
						this.model.getMessages().add(m);
					}
				} else {
					Message m = new Message();
					m.setTipo(Message.Type.INFO);
					m.setMensaje("no se ha cargado la receta");
					this.model.getMessages().add(m);
				}
			} else {
				r = "login";
			}
		} catch (SQLException e) {
			Message m = new Message();
			m.setTipo(Message.Type.ERROR);
			m.setMensaje("Se ha producido un error en el acceso a la base de datos"
					+ e.getMessage());
			this.model.getMessages().add(m);
			return "error";
		} catch (Exception e) {
			Message m = new Message();
			m.setTipo(Message.Type.ERROR);
			m.setMensaje("Se ha producido un error" + e.getMessage());
			this.model.getMessages().add(m);
			System.out.println(e.toString());
			return "error";
		}
		return r;
	}

	/**
	 * (non-Javadoc)
	 * 
	 * @see org.apache.struts2.interceptor.SessionAware#setSession(java.util.Map)
	 */
	@Override
	public void setSession(Map<String, Object> session) {
		this.session = session;
	}

	/**
	 * (non-Javadoc)
	 * 
	 * @see com.opensymphony.xwork2.ModelDriven#getModel()
	 */
	@Override
	public GR00Model getModel() {
		return this.model;
	}

}
